=====================
Appendix C. Changelog
=====================
:Info: This is the changelog for Cheqlist.
:Author: Chris Warrick <chris@chriswarrick.com>
:Copyright: © 2015, Chris Warrick.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2015-09-23
:Version: 0.1.2

.. index:: CHANGELOG

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/Kwpolska/cheqlist/releases>`_.

Version History
===============

0.1.2
    * Add menu bar
    * Add Quit action (Ctrl+Q)
    * Add Edit action (Ctrl+E)
    * Add actions to (un)check all and invert checks

0.1.1
    * .cheqlist extension
    * minor fixes
    * demo files

0.1.0
    Initial release.
